@@ -97,9 +97,9 @@ class dataset_1:
                 n_parents = len(self.parents)
                 n_data = len(self)
                 no_tries = max(100, int(round( log(2+n_parents)*(max(priors.values())/fpr_factor) )))
-                if max_tries>100:
-                    no_tries=min(no_tries,max_tries)
-                    
+                if max_tries:
+                    no_tries = min(no_tries, max_tries)
+                
                 self_empty = self.subset()
                 empty_score = score.data_score(self_empty) + score.graph_score(n_parents,self.vertex,[],n_data)
                 sample_scores = [[score.lower_bound_for_data_score(self_empty)]*n_parents]
