@@ -29,11 +29,11 @@ class score:
     To obtain a working implementation, one has to define methods graph_score and data_score
     """
     
-    def __init__(self,data_factor = 1.0,prior=None,sloops=0,**kwds):
+    def __init__(self,data_factor = 1.0,prior=None,sloops=False,**kwds):
         self.data_factor=data_factor
         self.sloops = sloops # do we allow self-loops in the networks ?
         
-    def graph_score(self,number_of_potential_parents,vertices,weights_of_parents,number_of_data_points, list_of_parents):
+    def graph_score(self,number_of_potential_parents,vertices,weights_of_parents,number_of_data_points):
         """
         Method for computing graph score factor - ABSTRACT method
 
@@ -97,8 +97,8 @@ class score:
         if verbose:
             print 'Learning parents of', selected_data.vertex.name, '...',
        
-        if not self.sloops:
-            selected_data.rm_sloops()
+#        if not self.sloops:
+#            selected_data.rm_sloops()
             
         v = selected_data.vertex
         nd = len(selected_data)
@@ -114,7 +114,7 @@ class score:
         mindata = self.lower_bound_for_data_score(selected_data_empty)
 
         min_set = minset(n_min,score_max,score_delta,self.data_score(selected_data_empty)+\
-                self.graph_score(n,v,[],nd,[])) #empty parents set
+                self.graph_score(n,v,[],nd)) #empty parents set
         if n: # are there any potential parents?
             w_min=p_weights[parents[0]]
             w_max=p_weights[parents[-1]]
@@ -122,7 +122,7 @@ class score:
                 weight=w_min
                 size = 1
                 
-                mg = self.graph_score(n,v,[weight],nd, [parents[0]])
+                mg = self.graph_score(n,v,[weight],nd)
                 while min_set.accepts(mg+mindata) and (size<=lim): #we can possibly add (sub-)optimal scores
 
                     for sub in self.subsets(parents,size):
@@ -131,12 +131,12 @@ class score:
                         min_set.add(mg+self.data_score(selected_data_sub), sub)
                     size+=1
                         
-                    mg = self.graph_score(n,v,[weight]*size,nd, sub+[parents[0]])
+                    mg = self.graph_score(n,v,[weight]*size,nd)
             else: # we have to use algorithm 1
                 subsets=[] #successors of considered yet potential parents sets
                 for parent in parents: #one-element parents sets
                     #print "one parent"
-                    heappush(subsets,(self.graph_score(n,v,[p_weights[parent]],nd, [parent]),[p_weights[parent]],[parent]))
+                    heappush(subsets, (self.graph_score(n,v,[p_weights[parent]],nd), [p_weights[parent]], [parent]) )
                 while subsets:
 		    #print subsets
                     mg,weights,sub=heappop(subsets)
@@ -151,7 +151,7 @@ class score:
                         for parent in parents[last_parent+1:]:
                             sub_succ=sub+[parent]
                             weights_succ=weights+[p_weights[parent]]
-                            mg_succ=self.graph_score(n,v,weights_succ,nd, sub_succ)
+                            mg_succ=self.graph_score(n,v,weights_succ,nd)
                             heappush(subsets,(mg_succ,weights_succ,sub_succ))
         if verbose:
             print 'done', min_set
@@ -169,7 +169,7 @@ class score:
         for i,v in enumerate(g.vertices):
             p = g.parents(v)
             selected_data = data.select_1(i,p)
-            sg = self.graph_score(n_vert,v,map(lambda par:par.n_disc,p),len(selected_data), p)
+            sg = self.graph_score(n_vert,v,map(lambda par:par.n_disc,p),len(selected_data))
             sd = self.data_score(selected_data)
             s+=sg+sd
         return s
